==> appfs-21.02.tar.gz: usr/local/www/berogui/modules/Security/security_submit.php <==
<?PHP
$m = 'Security';
$berogui_path = "/usr/local/www/berogui";

/* [CHECKING SESSION] */
$newTarget = "/app/berogui/index.php?m=$m";
include($berogui_path .'/includes/session.php');
unset($newTarget);

/* [INCLUDE] */
include('/usr/fallback/beroConf.php');
include($berogui_path ."/includes/password_func.php");
include_once($berogui_path ."/misc/database.php");
include_once($berogui_path ."/includes/Helper/Helper.php");

/* [FUNCTIONS] */
function setApiPassword($user, $pass) {
	require_once('/usr/local/php/include/apiusers.Class.php');
	$apiusers = new apiusers($pass);
	$apiusers->createFile();
}

function setGuiPassword($ba, $user, $pass) {
	$pass_enc = tep_encrypt_password($pass);
	$ba->update('UPDATE users SET password = \'' . $pass_enc . '\' WHERE user = \'' . $user . '\'');
}

function setPasswords($ba, $user, $pw_old, $pw_new, $pw_con) {
	# we do not like empty passwords
	if ((strlen($pw_new) == 0) || (strlen($pw_old) == 0) || (strlen($pw_con) == 0)) {
		return(1);
	}

	# old password should be correct
	$query = $ba->select('SELECT password FROM users WHERE user = \'' . $user . '\'');
	$pw_chk = $ba->fetch_array($query);
	if (tep_validate_password($pw_old, $pw_chk['password']) == false) {
		return(2);
	}
	unset($query);
	unset($pw_chk);

	# new password should be the same as confirmation
	if (strcmp($pw_new, $pw_con) != 0) {
		return(3);
	}

	switch ($user) {
		case 'admin':
			if ($ba->get('is_sbc_vm') != 1) {
				setApiPassword($user, $pw_new);
				setSshPassword($user, $pw_new);
			}
		case 'beroAdmin':
			setGuiPassword($ba, $user, $pw_new);
			break;
	}

	return(0);
}

function setSshLogin($bc, $enabled) {
	$bc->set('root', 'ssh_admin_enable', (($enabled == '1') ? '1' : '0'));
	$passwd = '/usr/bin/passwd -' . (($enabled == 1) ? 'u' : 'l') . ' admin';
	exec('/bin/mount -oremount,rw /; ' . $passwd . '; /bin/mount -oremount,ro /');
}

function setSshPassword($user, $pass) {
	exec('/usr/local/sbin/pwchange.sh admin ' . $pass);
}

/* [GLOBAL VARIABLES] */
$exec_ajax = 1;
$invalid = array();

/* [CHECKING SESSION VARIABLE] */
$_SESSION['beroari_username'] = Helper::sanitizeSession($_SESSION['beroari_username'], 'config-option', $exec_ajax, $invalid); // TODO: maybe, find a better checkor than 'config-option'

/* [CHECKING GET REQUEST] */
unset($_GET);

/* [CHECKING POST REQUEST] */
unset($_POST['m'], $_POST['f'], $_POST['fixChrome']);

// TOTEST: restore admin / password / username coming from an other script
$list_post = array(	
	'submit'    => 'select', 'a'	    => 'select'  , 'api_disable' => 'bool'    , 'ssh_admin_enable' => 'bool'	, 'show_app' => 'bool',	
	'safeguard' => 'bool'  , 'pass_old' => 'password', 'pass_new'    => 'password', 'pass_con'	   => 'password',
); 

$list_options = array(	
	'submit'	=> array('Restore admin password and username', 'Save', 'Speichern'), // must rework the class to work with BUTTON_SAVE
	'a'		=> array('save_password', 'save_settings'),
);

$_POST = Helper::sanitizePost($_POST, $list_post, $exec_ajax, $invalid, $list_options);

/* [EXECUTING AJAX] */
if (!$exec_ajax) {
        echo "<script>window.location='../../index.php?m=$m&error=1&request={$invalid['request']}&checkor={$invalid['checkor']}&key={$invalid['key']}'</script>";
        exit(1);
}

$ba = new beroAri();
$bc = new beroConf('root');

if ($_POST['submit'] == 'Restore admin password and username') {
	// from where come this submit ??
	$res = 0;
	setApiPassword('admin', 'admin');
	setSshPassword('admin', 'admin');
	setGuiPassword('admin', 'admin');
}
else if ($_POST['a'] == 'save_password') {
	$res = -1;
	// only try to update password if some of the password-fields are set
	if ((strlen($_POST['pass_old']) != 0) || (strlen($_POST['pass_new']) != 0) || (strlen($_POST['pass_con']) != 0)) {
		if (($res = setPasswords($ba, $_SESSION['beroari_username'], $_POST['pass_old'], $_POST['pass_new'], $_POST['pass_con'])) == 0) {
			Helper::activate(1, true, $m, ACTIVATE);
		}
	}
	echo "<script>window.location='../../index.php?m=$m&response=$res'</script>";
}
else if ($_POST['a'] == 'save_settings') {
	$activate_level = 1;
	$bc->set('root', 'api_disable', (($_POST['api_disable'] == '1') ? '1' : '0'));

	setSshLogin($bc, $_POST['ssh_admin_enable']);
	// keep old show_app settings; and set it to 0 for always allowing the API-Sessions
	$ba->update("UPDATE set_app SET show_app='0'");

	if ((($bc->get('root', 'safeguard') == '1') ? '1' : '0') != (($_POST['safeguard'] == '1') ? '1' : '0')) {
		$bc->set('root', 'safeguard', (($_POST['safeguard'] == '1') ? '1' : '0'));
		$activate_level = 2;
	}
	Helper::activate($activate_level, true, $m, ACTIVATE);
	echo "<script>window.location='../../index.php?m=$m'</script>";
}

exit(1);

==> appfs-24.01.02-rc05.tar.gz: usr/local/www/berogui/modules/Security/security_submit.php <==
<?PHP
$m = 'Security';
$berogui_path = "/usr/local/www/berogui";

/* [CHECKING SESSION] */
$newTarget = "/app/berogui/index.php?m=$m";
include($berogui_path .'/includes/session.php');
unset($newTarget);

/* [INCLUDE] */
include('/usr/fallback/beroConf.php');
include($berogui_path ."/includes/password_func.php");
include_once($berogui_path ."/misc/database.php");
include_once($berogui_path ."/includes/Helper/Helper.php");

/* [FUNCTIONS] */
function setApiPassword($user, $pass) {
	require_once('/usr/local/php/include/apiusers.Class.php');
	$apiusers = new apiusers($pass);
	$apiusers->createFile();
}

function setGuiPassword($ba, $user, $pass) {
	$pass_enc = tep_encrypt_password($pass);
	$ba->update('UPDATE users SET password = \'' . $pass_enc . '\' WHERE user = \'' . $user . '\'');
	system ("sed -i 's/admin-pass=.*/admin-pass=" . $pass_enc . "/'  /usr/conf/misc.conf");
}

function setPasswords($ba, $user, $pw_old, $pw_new, $pw_con) {
	# we do not like empty passwords
	if ((strlen($pw_new) == 0) || (strlen($pw_old) == 0) || (strlen($pw_con) == 0)) {
		return(1);
	}

	# old password should be correct
	$query = $ba->select('SELECT password FROM users WHERE user = \'' . $user . '\'');
	$pw_chk = $ba->fetch_array($query);
	if (tep_validate_password($pw_old, $pw_chk['password']) == false) {
		return(2);
	}
	unset($query);
	unset($pw_chk);

	# new password should be the same as confirmation
	if (strcmp($pw_new, $pw_con) != 0) {
		return(3);
	}

	switch ($user) {
		case 'admin':
			if ($ba->get('is_sbc_vm') != 1) {
				setApiPassword($user, $pw_new);
				setSshPassword($user, $pw_new);
			}
		case 'beroAdmin':
			setGuiPassword($ba, $user, $pw_new);
			break;
	}

	return(0);
}

function setSshLogin($bc, $enabled) {
	$bc->set('root', 'ssh_admin_enable', (($enabled == '1') ? '1' : '0'));
	$passwd = '/usr/bin/passwd -' . (($enabled == 1) ? 'u' : 'l') . ' admin';
	exec('/bin/mount -oremount,rw /; ' . $passwd . '; /bin/mount -oremount,ro /');
}

function setSshPassword($user, $pass) {
	exec('/usr/local/sbin/pwchange.sh admin ' . $pass);
}

/* [GLOBAL VARIABLES] */
$exec_ajax = 1;
$invalid = array();

/* [CHECKING SESSION VARIABLE] */
$_SESSION['beroari_username'] = Helper::sanitizeSession($_SESSION['beroari_username'], 'config-option', $exec_ajax, $invalid); // TODO: maybe, find a better checkor than 'config-option'

/* [CHECKING GET REQUEST] */
unset($_GET);

/* [CHECKING POST REQUEST] */
unset($_POST['m'], $_POST['f'], $_POST['fixChrome']);

// TOTEST: restore admin / password / username coming from an other script
$list_post = array(	
	'submit'    => 'select', 'a'	    => 'select'  , 'api_disable' => 'bool'    , 'ssh_admin_enable' => 'bool'	, 'show_app' => 'bool',	
	'safeguard' => 'bool'  , 'pass_old' => 'password', 'pass_new'    => 'password', 'pass_con'	   => 'password',
); 

$list_options = array(	
	'submit'	=> array('Restore admin password and username', 'Save', 'Speichern'), // must rework the class to work with BUTTON_SAVE
	'a'		=> array('save_password', 'save_settings'),
);

$_POST = Helper::sanitizePost($_POST, $list_post, $exec_ajax, $invalid, $list_options);

/* [EXECUTING AJAX] */
if (!$exec_ajax) {
        echo "<script>window.location='../../index.php?m=$m&error=1&request={$invalid['request']}&checkor={$invalid['checkor']}&key={$invalid['key']}'</script>";
        exit(1);
}

$ba = new beroAri();
$bc = new beroConf('root');

if ($_POST['submit'] == 'Restore admin password and username') {
	// from where come this submit ??
	$res = 0;
	setApiPassword('admin', 'admin');
	setSshPassword('admin', 'admin');
	setGuiPassword('admin', 'admin');
}
else if ($_POST['a'] == 'save_password') {
	$res = -1;
	// only try to update password if some of the password-fields are set
	if ((strlen($_POST['pass_old']) != 0) || (strlen($_POST['pass_new']) != 0) || (strlen($_POST['pass_con']) != 0)) {
		if (($res = setPasswords($ba, $_SESSION['beroari_username'], $_POST['pass_old'], $_POST['pass_new'], $_POST['pass_con'])) == 0) {
			//Helper::activate(1, true, $m, ACTIVATE);
		}
	}
	echo "<script>window.location='../../index.php?m=$m&response=$res'</script>";
}
else if ($_POST['a'] == 'save_settings') {
	$activate_level = 1;
	$bc->set('root', 'api_disable', (($_POST['api_disable'] == '1') ? '1' : '0'));

	setSshLogin($bc, $_POST['ssh_admin_enable']);
	// keep old show_app settings; and set it to 0 for always allowing the API-Sessions
	$ba->update("UPDATE set_app SET show_app='0'");

	if ((($bc->get('root', 'safeguard') == '1') ? '1' : '0') != (($_POST['safeguard'] == '1') ? '1' : '0')) {
		$bc->set('root', 'safeguard', (($_POST['safeguard'] == '1') ? '1' : '0'));
		$activate_level = 2;
	}
	Helper::activate($activate_level, true, $m, ACTIVATE);
	echo "<script>window.location='../../index.php?m=$m'</script>";
}

exit(1);
